@@ -14,13 +14,14 @@
 #'   nt = 250L,
 #'   prob_ice = 0.5,
 #'   fu_max = 336L,
+#'   prop_cens = 0.15,
 #'   T0T_rate = 0.2,
 #'   T0N_rate = 0.2,
 #'   T1T_rate = 0.15,
 #'   T1N_rate = 0.1
 #' )
 #' dat_mult_trials <- sim_dat_mult_trials_exp_nocovar(
-#'   n_iter = 3,
+#'   n_iter = 3L,
 #'   params = d_params_nocovar 
 #' )
 #' lapply(dat_mult_trials, dim)
@@ -34,12 +35,13 @@ sim_dat_mult_trials_exp_nocovar <- function(n_iter, params) {
       nt = params[["nt"]],
       prob_ice = params[["prob_ice"]],
       fu_max = params[["fu_max"]],
+      prop_cens   = params[["prop_cens"]],
       T0T_rate = params[["T0T_rate"]],
       T0N_rate = params[["T0N_rate"]],
       T1T_rate = params[["T1T_rate"]],
       T1N_rate = params[["T1N_rate"]]
     ),
-    simplify = F
+    simplify = FALSE
   ) %>%
     lapply(FUN = function(x) x[!(names(x) %in% c("PAT_ID","T0N","T0T","T1N","T1T"))])
-}
\ No newline at end of file
+}
